aboutsummaryrefslogtreecommitdiffstats
path: root/railties/helpers/application.rb
diff options
context:
space:
mode:
Diffstat (limited to 'railties/helpers/application.rb')
-rw-r--r--railties/helpers/application.rb5
1 files changed, 4 insertions, 1 deletions
diff --git a/railties/helpers/application.rb b/railties/helpers/application.rb
index 043488903d..0a72bba2c9 100644
--- a/railties/helpers/application.rb
+++ b/railties/helpers/application.rb
@@ -3,5 +3,8 @@
class ApplicationController < ActionController::Base
helper :all # include all helpers, all the time
- protect_from_forgery # See ActionController::RequestForgeryProtection for details
+
+ # See ActionController::RequestForgeryProtection for details
+ # If you're using the Cookie Session Store you can leave out the :secret
+ protect_from_forgery :secret => '<%= app_secret %>'
end \ No newline at end of file